@@ -40,10 +40,17 @@ class ConcurrentUart(AbstractAsyncSerial):
     WriteBufferEndOfTransmission = '\4'
 
     @classmethod
-    def new_default(cls, port: str, baudrate: int, loop: typing.Optional[asyncio.AbstractEventLoop] = None) -> 'ConcurrentUart':
+    def new_default(cls,
+                    port: str,
+                    baudrate: int,
+                    loop: typing.Optional[asyncio.AbstractEventLoop] = None) -> 'ConcurrentUart':
         return cls(serial.Serial(port=port, baudrate=baudrate, timeout=cls.DefaultSerialTimeoutSeconds), loop)
 
-    def __init__(self, serial_port: serial.Serial, loop: typing.Optional[asyncio.AbstractEventLoop] = None, eol: str = '\r\n', echo: bool = False) -> None:
+    def __init__(self,
+                 serial_port: serial.Serial,
+                 loop: typing.Optional[asyncio.AbstractEventLoop] = None,
+                 eol: str = '\r\n',
+                 echo: bool = False) -> None:
         super().__init__(loop)
         self._s = serial_port
         self._echo = echo
@@ -52,6 +59,7 @@ class ConcurrentUart(AbstractAsyncSerial):
         self._serial_futures = []  # type: typing.List[concurrent.futures.Future]
         self._logger_tx = logging.getLogger(type(self).__name__ + "_tx")
         self._logger_rx = logging.getLogger(type(self).__name__ + "_rx")
+        self._extra_verbose = False
 
     @property
     def serial_port(self) -> serial.Serial:
@@ -81,6 +89,14 @@ class ConcurrentUart(AbstractAsyncSerial):
     def timeout_seconds(self, value: float) -> None:
         self._s.timeout = value
 
+    @property
+    def extra_verbose(self) -> bool:
+        return self._extra_verbose
+
+    @extra_verbose.setter
+    def extra_verbose(self, extra_verbose: bool) -> None:
+        self._extra_verbose = extra_verbose
+
     # +-----------------------------------------------------------------------+
     # | CONTEXT MANAGER
     # +-----------------------------------------------------------------------+
@@ -94,7 +110,7 @@ class ConcurrentUart(AbstractAsyncSerial):
         return self
 
     def __exit__(self,
-                 exception_type: typing.Optional[typing.Any],  # for python3.6+ this should be typing.Optional[typing.Type]
+                 exception_type: typing.Optional[typing.Any],
                  exception_value: typing.Optional[typing.Any],
                  traceback: typing.Optional[types.TracebackType]) -> None:
         self.stop()
@@ -112,12 +128,26 @@ class ConcurrentUart(AbstractAsyncSerial):
     # +-----------------------------------------------------------------------+
 
     def readline(self) -> typing.Optional[TimestampedLine]:
+        """
+        Get a line of text from the receive buffers.
+
+        :returns: A line of text with the time it was received at.
+        :rtype: TimestampedLine
+        """
         try:
             return self._read_buffer.get_nowait()
         except queue.Empty:
             return None
 
     def writeline(self, input_line: str, end: typing.Optional[str] = None) -> float:
+        """
+        Enqueue a line of text to be transmitted on the serial device.
+
+        :param str input_line: The line to put.
+        :param end: Line ending (overrides the default :meth:`eol`).
+        :type end: typing.Optional[str]
+        :return: The monotonic system time that the line was put into the serial buffers at (see :meth:`time`).
+        """
         try:
             self._write_buffer.put_nowait(input_line + (end if end is not None else self._eol))
             return self.time()
@@ -154,9 +184,10 @@ class ConcurrentUart(AbstractAsyncSerial):
             try:
                 timestamped_line = TimestampedLine.create(decoded_line, rx_timestamp_seconds)
                 self._read_buffer.put_nowait(timestamped_line)
-                self._logger_rx.debug(re.sub('\\r', '<cr>', timestamped_line))
+                if self._extra_verbose:
+                    self._logger_rx.debug(re.sub('\\r', '<cr>', timestamped_line))
             except queue.Full:
-                self._logger_rx.warn("read buffer overflow.")
+                self._logger_rx.warning("read buffer overflow.")
                 self._rx_buffer_overflows += 1
 
     def _buffer_output(self) -> None:
@@ -174,6 +205,6 @@ class ConcurrentUart(AbstractAsyncSerial):
             if writeline != self.WriteBufferEndOfTransmission:
                 self._s.write(self._tx_encoder.encode(writeline))
                 if self._echo:
-                    self._logger_tx.debug(re.sub('\\r', '<cr>', writeline))
+                    self._logger_tx.info(re.sub('\\r', '<cr>', writeline))
         except queue.Empty:
             pass
